#
# spec file for package osmo-iuh
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2021 sysmocom - s.f.m.c GmbH
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

Name:           osmo-iuh
Version:        1.5.1
Release:        0
Summary:        Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Hardware/Mobile
URL:            https://osmocom.org/projects/osmohnbgw
Source:         %{name}-%{version}.tar.xz
BuildRequires:  automake >= 1.9
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkgconfig >= 0.20
# python3 for asn1tostruct.py
BuildRequires:  python3
BuildRequires:  pkgconfig(libasn1c) >= 0.9.30
BuildRequires:  pkgconfig(libosmocore) >= 1.9.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.9.0
BuildRequires:  pkgconfig(libosmogb) >= 1.9.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.9.0
BuildRequires:  pkgconfig(libosmovty) >= 1.9.0
BuildRequires:  pkgconfig(libosmo-netif) >= 1.4.0
BuildRequires:  pkgconfig(libosmo-sigtran) >= 1.8.0

%description
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-hnbap0
Summary:        Shared Library part of libosmo-hnbap
Group:          System/Libraries

%description -n libosmo-hnbap0
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-hnbap-devel
Summary:        Development files for Osmocom HNBAP library
Group:          Development/Libraries/C and C++
Requires:       libosmo-hnbap0 = %{version}

%description -n libosmo-hnbap-devel
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-ranap7
Summary:        Shared Library part of libosmo-ranap
Group:          System/Libraries

%description -n libosmo-ranap7
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-ranap-devel
Summary:        Development files for Osmocom RANAP library
Group:          Development/Libraries/C and C++
Requires:       libosmo-ranap7 = %{version}

%description -n libosmo-ranap-devel
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

This subpackage contains libraries and header files for developing
applications that want to make use of libosmoranap.

%package -n libosmo-rua0
Summary:        Shared Library part of libosmo-rua
Group:          System/Libraries

%description -n libosmo-rua0
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-rua-devel
Summary:        Development files for Osmocom RUA library
Group:          Development/Libraries/C and C++
Requires:       libosmo-rua0 = %{version}

%description -n libosmo-rua-devel
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-sabp1
Summary:        Shared Library part of libosmo-sabp
Group:          System/Libraries

%description -n libosmo-sabp1
Osmocom code for the SABP (service area broadcast protocol) interface

%package -n libosmo-sabp-devel
Summary:        Development files for Osmocom SABP library
Group:          Development/Libraries/C and C++
Requires:       libosmo-sabp1 = %{version}

%description -n libosmo-sabp-devel
Osmocom code for the SABP (service area broadcast protocol) interface

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-sabp.


%prep
%setup -q

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
  --disable-static \
  --docdir="%{_docdir}/%{name}"
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%post   -n libosmo-hnbap0 -p /sbin/ldconfig
%postun -n libosmo-hnbap0 -p /sbin/ldconfig
%post   -n libosmo-ranap7 -p /sbin/ldconfig
%postun -n libosmo-ranap7 -p /sbin/ldconfig
%post   -n libosmo-rua0 -p /sbin/ldconfig
%postun -n libosmo-rua0 -p /sbin/ldconfig
%post   -n libosmo-sabp1 -p /sbin/ldconfig
%postun -n libosmo-sabp1 -p /sbin/ldconfig

%files
%license COPYING
%doc README.md

%files -n libosmo-hnbap0
%{_libdir}/libosmo-hnbap.so.0*

%files -n libosmo-hnbap-devel
%dir %{_includedir}/osmocom/
%dir %{_includedir}/osmocom/hnbap/
%{_includedir}/osmocom/hnbap/*
%{_libdir}/libosmo-hnbap.so
%{_libdir}/pkgconfig/libosmo-hnbap.pc

%files -n libosmo-ranap7
%{_libdir}/libosmo-ranap.so.7*

%files -n libosmo-ranap-devel
%dir %{_includedir}/osmocom/
%dir %{_includedir}/osmocom/ranap/
%{_includedir}/osmocom/ranap/*
%{_libdir}/libosmo-ranap.so
%{_libdir}/pkgconfig/libosmo-ranap.pc

%files -n libosmo-rua0
%{_libdir}/libosmo-rua.so.0*

%files -n libosmo-rua-devel
%dir %{_includedir}/osmocom/
%dir %{_includedir}/osmocom/rua/
%{_includedir}/osmocom/rua/*
%{_libdir}/libosmo-rua.so
%{_libdir}/pkgconfig/libosmo-rua.pc

%files -n libosmo-sabp1
%{_libdir}/libosmo-sabp.so.1*

%files -n libosmo-sabp-devel
%dir %{_includedir}/osmocom/
%dir %{_includedir}/osmocom/sabp/
%{_includedir}/osmocom/sabp/*
%{_libdir}/libosmo-sabp.so
%{_libdir}/pkgconfig/libosmo-sabp.pc

%changelog
